tonsky/FiraCode
Monospaced font with programming ligatures. Contribute to tonsky/FiraCode development by creating an account on GitHub.
Monospaced font with programming ligatures. Contribute to tonsky/FiraCode development by creating an account on GitHub.
Moves the crossgen2 sources from the CoreRT repo. TODO: Commit as dotnet-bot Build fixes (we probably want to do a self-contained publish for now) Coordinate move day with other contributors R...
// Type your code here, or load an example. __global__ void square(int *array, int n) { int tid = blockIdx.x; if (tid < n) array[tid] = array[tid] * array[tid]; }
Nedbank confirmed that it has temporarily disabled the ability for users to copy-and-paste their username and password into the bank’s login portal.
The LLBLGen Pro Blog: 16 years of LLBLGen Pro!
Python 2.7 will retire in 2020. Learn more and see the countdown here.
The .NET MVVM framework for cross-platform solutions, including Xamarin.iOS, Xamarin.Android, Windows and Mac. - MvvmCross/MvvmCross
Today’s blog post is an overview of some common optimization techniques and neat tricks for doing “systems programming” – whatever that means today. We’ll walk through some methods to make your code run faster, be more efficient, and to squeeze just a little m…
I've spoken a lot about Certificate Transparency on my blog recently and how powerful it is for site operators to be able to keep track of certificates issued for their domains. We plan to make that even easier by integrating CT monitoring into Report URI. Ce…
The Australian Government is developing our nation’s next Cyber Security Strategy as part of its commitment to protecting Australians from cyber threats.